from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Connector:
	"""Connector commands group definition. 7 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("connector", core, parent)

	@property
	def refLo(self):
		"""refLo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refLo'):
			from .Connector_.RefLo import RefLo
			self._refLo = RefLo(self._core, self._base)
		return self._refLo

	@property
	def user(self):
		"""user commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_user'):
			from .Connector_.User import User
			self._user = User(self._core, self._base)
		return self._user

	def clone(self) -> 'Connector':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Connector(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
